Package 'VRData'

Title: This is a data package for the spawner and fraction wild data used in the NWFSC PNW Salmonid Viability Reports.
Description:
Authors: Holmes Elizabeth [aut, cre]
Maintainer: Elizabeth Holmes - NOAA Federal <[email protected]>
License: GPL-2
Version: 1.0
Built: 2026-05-16 08:11:44 UTC
Source: https://github.com/jimianelli/VRData

Help Index


Columbia River Chum Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Columbia-River-Chum-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Columbia-River-Chum-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Hood Canal Summer-run Chum Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Hood-Canal-Summer-run-Chum-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Hood-Canal-Summer-run-Chum-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Lower Columbia River Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Lower-Columbia-River-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Lower-Columbia-River-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Lower Columbia River Coho Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Lower-Columbia-River-Coho-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Lower-Columbia-River-Coho-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Lower Columbia River Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Lower-Columbia-River-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Lower-Columbia-River-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

Middle Columbia River Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Middle-Columbia-River-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Middle-Columbia-River-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

Oregon Coast Coho Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Oregon-Coast-Coho-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Oregon-Coast-Coho-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Ozette Lake Sockeye Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Ozette-Lake-Sockeye-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Ozette-Lake-Sockeye-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Puget Sound Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Puget-Sound-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Puget-Sound-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Puget Sound Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Puget-Sound-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Puget-Sound-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

Snake River Basin Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Snake-River-Basin-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Snake-River-Basin-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

Snake River Fall-run Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Snake-River-Fall-run-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Snake-River-Fall-run-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Snake River Spring-Summer-run Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Upper Columbia River Spring-run Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Upper Columbia River Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Upper-Columbia-River-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Upper-Columbia-River-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

Upper Willamette River Chinook Salmon ESU

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Upper-Willamette-River-Chinook-Salmon-ESU')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Upper-Willamette-River-Chinook-Salmon-ESU') +
  facet_wrap(~COMMON_POPULATION_NAME)

Upper Willamette River Steelhead DPS

Description

Spawner counts and fraction wild data.

Format

A csv file.

NMFS_POPID

NWFSC id for the population.

ESU

ESU or DPS name.

SPECIES

Species name.

RUN_TIMING

Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.

MAJOR_POPULATION_GROUP

Major population group within the ESU or DPS.

COMMON_POPULATION_NAME

Population name.

YEAR

The year that the count was made.

NUMBER_OF_SPAWNERS

Spawners count. -99 means missing count.

FRACWILD

Fraction wild. -99 means missing information.

Details

Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016

Author(s)

Monica Diaz (NOAA/NWFSC)

Examples

data('Upper-Willamette-River-Steelhead-DPS')
library(ggplot2)
out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA
ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) +
  ggtitle('Upper-Willamette-River-Steelhead-DPS') +
  facet_wrap(~COMMON_POPULATION_NAME)

VRData names

Description

Allowed values for data columns. #'

Format

A vector of names. #'

esu_dps

Allowed ESU or DPS names.

(speciesAllowed species names. \item(run_timing

Author(s)

Eli Holmes (NOAA)

Examples

data('vrdata_names')
cat(c("ESU and DPS", esu_dps), sep="\n")
cat(c("\n", "Species", species), sep="\n")
cat(c("\n", "Run Timing", run_timing), sep="\n")