| Title: | This is a data package for the spawner and fraction wild data used in the NWFSC PNW Salmonid Viability Reports. |
|---|---|
| Description: | |
| Authors: | Holmes Elizabeth [aut, cre] |
| Maintainer: | Elizabeth Holmes - NOAA Federal <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0 |
| Built: | 2026-05-16 08:11:44 UTC |
| Source: | https://github.com/jimianelli/VRData |
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Columbia-River-Chum-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Columbia-River-Chum-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Columbia-River-Chum-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Columbia-River-Chum-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Hood-Canal-Summer-run-Chum-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Hood-Canal-Summer-run-Chum-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Hood-Canal-Summer-run-Chum-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Hood-Canal-Summer-run-Chum-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Lower-Columbia-River-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Lower-Columbia-River-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Lower-Columbia-River-Coho-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Coho-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Lower-Columbia-River-Coho-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Coho-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Lower-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Lower-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Lower-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Middle-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Middle-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Middle-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Middle-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Oregon-Coast-Coho-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Oregon-Coast-Coho-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Oregon-Coast-Coho-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Oregon-Coast-Coho-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Ozette-Lake-Sockeye-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Ozette-Lake-Sockeye-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Ozette-Lake-Sockeye-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Ozette-Lake-Sockeye-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Puget-Sound-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Puget-Sound-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Puget-Sound-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Puget-Sound-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Puget-Sound-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Puget-Sound-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Puget-Sound-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Puget-Sound-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Snake-River-Basin-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Basin-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Snake-River-Basin-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Basin-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Snake-River-Fall-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Fall-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Snake-River-Fall-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Fall-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Snake-River-Spring-Summer-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Columbia-River-Spring-run-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Upper-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Upper-Columbia-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Columbia-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Upper-Willamette-River-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Willamette-River-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)data('Upper-Willamette-River-Chinook-Salmon-ESU') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Willamette-River-Chinook-Salmon-ESU') + facet_wrap(~COMMON_POPULATION_NAME)
Spawner counts and fraction wild data.
A csv file.
NWFSC id for the population.
ESU or DPS name.
Species name.
Run timing (fall, winter, spring, etc). If missing, see the ESU/DPS name or may not be applicable for the species.
Major population group within the ESU or DPS.
Population name.
The year that the count was made.
Spawners count. -99 means missing count.
Fraction wild. -99 means missing information.
Downloaded from the SPS Master Oracle 2013-2014 Database on January 28, 2016
Monica Diaz (NOAA/NWFSC)
data('Upper-Willamette-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Willamette-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)data('Upper-Willamette-River-Steelhead-DPS') library(ggplot2) out$NUMBER_OF_SPAWNERS[out$NUMBER_OF_SPAWNERS==-99] <- NA ggplot(out, aes(x=YEAR, y=NUMBER_OF_SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Upper-Willamette-River-Steelhead-DPS') + facet_wrap(~COMMON_POPULATION_NAME)
Allowed values for data columns. #'
A vector of names. #'
Allowed ESU or DPS names.
(speciesAllowed species names. \item(run_timing
Eli Holmes (NOAA)
data('vrdata_names') cat(c("ESU and DPS", esu_dps), sep="\n") cat(c("\n", "Species", species), sep="\n") cat(c("\n", "Run Timing", run_timing), sep="\n")data('vrdata_names') cat(c("ESU and DPS", esu_dps), sep="\n") cat(c("\n", "Species", species), sep="\n") cat(c("\n", "Run Timing", run_timing), sep="\n")